/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.devicefarm.model;

import java.io.Serializable;
import com.amazonaws.AmazonWebServiceRequest;

/**
 * <p>
 * A request representing an offering renewal.
 * </p>
 */
public class RenewOfferingRequest extends AmazonWebServiceRequest implements
        Serializable, Cloneable {

    /**
     * <p>
     * The ID of a request to renew an offering.
     * </p>
     */
    private String offeringId;
    /**
     * <p>
     * The quantity requested in an offering renewal.
     * </p>
     */
    private Integer quantity;

    /**
     * <p>
     * The ID of a request to renew an offering.
     * </p>
     * 
     * @param offeringId
     *        The ID of a request to renew an offering.
     */

    public void setOfferingId(String offeringId) {
        this.offeringId = offeringId;
    }

    /**
     * <p>
     * The ID of a request to renew an offering.
     * </p>
     * 
     * @return The ID of a request to renew an offering.
     */

    public String getOfferingId() {
        return this.offeringId;
    }

    /**
     * <p>
     * The ID of a request to renew an offering.
     * </p>
     * 
     * @param offeringId
     *        The ID of a request to renew an offering.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public RenewOfferingRequest withOfferingId(String offeringId) {
        setOfferingId(offeringId);
        return this;
    }

    /**
     * <p>
     * The quantity requested in an offering renewal.
     * </p>
     * 
     * @param quantity
     *        The quantity requested in an offering renewal.
     */

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    /**
     * <p>
     * The quantity requested in an offering renewal.
     * </p>
     * 
     * @return The quantity requested in an offering renewal.
     */

    public Integer getQuantity() {
        return this.quantity;
    }

    /**
     * <p>
     * The quantity requested in an offering renewal.
     * </p>
     * 
     * @param quantity
     *        The quantity requested in an offering renewal.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public RenewOfferingRequest withQuantity(Integer quantity) {
        setQuantity(quantity);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getOfferingId() != null)
            sb.append("OfferingId: " + getOfferingId() + ",");
        if (getQuantity() != null)
            sb.append("Quantity: " + getQuantity());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof RenewOfferingRequest == false)
            return false;
        RenewOfferingRequest other = (RenewOfferingRequest) obj;
        if (other.getOfferingId() == null ^ this.getOfferingId() == null)
            return false;
        if (other.getOfferingId() != null
                && other.getOfferingId().equals(this.getOfferingId()) == false)
            return false;
        if (other.getQuantity() == null ^ this.getQuantity() == null)
            return false;
        if (other.getQuantity() != null
                && other.getQuantity().equals(this.getQuantity()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode
                + ((getOfferingId() == null) ? 0 : getOfferingId().hashCode());
        hashCode = prime * hashCode
                + ((getQuantity() == null) ? 0 : getQuantity().hashCode());
        return hashCode;
    }

    @Override
    public RenewOfferingRequest clone() {
        return (RenewOfferingRequest) super.clone();
    }
}